@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2022-07-19 10:50:05
+@LastEditTime: 2023-01-12 15:17:18
 @LastEditors: HuangJianYi
 @Description: 
 """
+from seven_cloudapp_frame.models.enum import PageCountMode
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.act_base_model import *
@@ -62,15 +63,17 @@ class ActPrizeListHandler(ClientBaseHandler):
         :param ascription_type: 奖品归属类型（0-活动奖品1-任务奖品）
         :param page_size: 条数
         :param page_index: 页数
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return: PageInfo
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        module_id = int(self.get_param("module_id", 0))
+        module_id = self.get_param_int("module_id", 0)
         prize_name = self.get_param("prize_name")
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 10)
+        page_count_mode = self.get_param_int("page_count_mode", 1)
 
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
@@ -78,9 +81,19 @@ class ActPrizeListHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
-        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, 0, page_size, page_index)
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
-        return self.response_json_success(page_info)
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
+        page_list = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, 0, page_size, page_index, condition="is_release=1", page_count_mode=page_count_mode)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params={})
+        return self.response_json_success(return_info)
 
 
 class CmsInfoListHandler(ClientBaseHandler):
@@ -92,14 +105,17 @@ class CmsInfoListHandler(ClientBaseHandler):
         """
         :description: 获取位置信息列表
         :params place_id:位置标识
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        place_id = int(self.get_param("place_id", 0))
-        page_size = int(self.get_param("page_size", 20))
-        page_index = int(self.get_param("page_index", 0))
+        place_id = self.get_param_int("place_id", 0)
+        page_size = self.get_param_int("page_size", 20)
+        page_index = self.get_param_int("page_index", 0)
+        page_count_mode = self.get_param_int("page_count_mode", 1)
+
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -109,9 +125,19 @@ class CmsInfoListHandler(ClientBaseHandler):
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_list, total = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True)
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
-        return self.response_json_success(page_info)
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
+        page_list = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True, page_count_mode=page_count_mode)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params={})
+        return self.response_json_success(return_info)
 
 
 class PriceGearListHandler(ClientBaseHandler):
@@ -125,19 +151,31 @@ class PriceGearListHandler(ClientBaseHandler):
         :param act_id：活动标识
         :param page_index：页索引
         :param page_size：页大小
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return: list
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        page_size = self.get_param_int("page_size", 20)
+        page_index = self.get_param_int("page_index", 0)
+        page_count_mode = self.get_param_int("page_count_mode", 1)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
-        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by)
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
-        return self.response_json_success(page_info)
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
+        page_list = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by, page_count_mode=page_count_mode)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params={})
+        return self.response_json_success(return_info)
