@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2022-08-16 13:55:36
+@LastEditTime: 2023-01-04 15:04:40
 @LastEditors: HuangJianYi
 @Description: 
 """
+from seven_cloudapp_frame.models.enum import PageCountMode
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.order_base_model import *
 from seven_cloudapp_frame.models.stat_base_model import *
@@ -139,6 +140,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         :param page_index：页索引
         :param order_by：排序
         :param is_search_roster：是否查询订单关联中奖记录
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return: 
         :last_editors: HuangJianYi
         """
@@ -146,22 +148,21 @@ class PrizeOrderListHandler(ClientBaseHandler):
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
-        order_status = int(self.get_param("order_status",-10))
+        order_status = self.get_param_int("order_status", -10)
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","id desc")
-        is_search_roster = int(self.get_param("is_search_roster", 0))
-        if is_search_roster == 0:
-            is_search_roster = False
-        else:
-            is_search_roster = True
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
+        is_search_roster = self.get_param_int("is_search_roster", 0)
+        is_search_roster = False if is_search_roster == 0 else True
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 10)
+        page_count_mode = self.get_param_int("page_count_mode", 1)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
@@ -169,11 +170,19 @@ class PrizeOrderListHandler(ClientBaseHandler):
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
-        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, field, is_search_roster=is_search_roster, is_cache=True, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
+        page_list = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, field, is_search_roster=is_search_roster, is_cache=True, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode=page_count_mode)
         ref_params = {}
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
-
-        return self.response_json_success(page_info)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params=ref_params)
+        return self.response_json_success(return_info)
 
 
 class PrizeRosterListHandler(ClientBaseHandler):
@@ -195,6 +204,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         :param pay_status：支付状态(0未支付1已支付2已退款3处理中)
         :param page_size：页大小
         :param page_index：页索引
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return PageInfo
         :last_editors: HuangJianYi
         """
@@ -211,16 +221,28 @@ class PrizeRosterListHandler(ClientBaseHandler):
         pay_status = int(self.get_param("pay_status", -1))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
+        page_count_mode = self.get_param_int("page_count_mode", 1)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-
-        order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_roster_list(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, open_id=open_id, order_no=order_no, goods_type=goods_type, prize_type=prize_type, logistics_status=logistics_status, prize_status=prize_status, pay_status=pay_status, page_size=page_size, page_index=page_index)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode,page_count_mode)
         ref_params = {}
-        page_info.data = self.business_process_executed(page_info.data, ref_params)
-        return self.response_json_success(page_info)
+        order_base_model = OrderBaseModel(context=self)
+        page_list = order_base_model.get_prize_roster_list(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, open_id=open_id, order_no=order_no, goods_type=goods_type, prize_type=prize_type, logistics_status=logistics_status, prize_status=prize_status, pay_status=pay_status, page_size=page_size, page_index=page_index, page_count_mode=page_count_mode)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params=ref_params)
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params=ref_params)
+        return self.response_json_success(return_info)
 
 
 class SubmitSkuHandler(ClientBaseHandler):
@@ -243,7 +265,7 @@ class SubmitSkuHandler(ClientBaseHandler):
         user_prize_id = int(self.get_param("user_prize_id"))
         sku_name = self.get_param("sku_name")
         sku_id = self.get_param("sku_id")
-        
+
         prize_roster_model = PrizeRosterModel(context=self)
         prize_roster = prize_roster_model.get_entity_by_id(user_prize_id)
         if not prize_roster or prize_roster.open_id != open_id or prize_roster.app_id != app_id:
