@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-11-17 09:37:05
+@LastEditTime: 2023-01-04 15:57:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -452,7 +452,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                                 tiktok_goods_id_list = []
                                 if asset_type == 3:
                                     price_base_model = PriceBaseModel(context=self)
-                                    price_gear_dict_list,total = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0)
+                                    price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0, page_count_mode='none')
                                     for price_gear_dict in price_gear_dict_list:
                                         tiktok_goods_id_list.append(price_gear_dict["goods_id"])
                                 else:
