@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-11-28 14:05:17
+@LastEditTime: 2023-01-30 14:53:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -28,6 +28,7 @@ class TaskInfoListHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
+        mix_nick = self.get_param("mix_nick")
         module_id = int(self.get_param("module_id", 0))
         task_types = self.get_param("task_types")
         is_log = int(self.get_param("is_log", 0))
@@ -40,7 +41,7 @@ class TaskInfoListHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
-        result_list,task_info_list,task_count_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse)
+        result_list,task_info_list,task_count_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse, mix_nick)
         ref_params = {}
         ref_params["task_info_list"] = task_info_list
         ref_params["task_count_list"] = task_count_list
@@ -109,7 +110,7 @@ class FreeGiftHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -152,7 +153,7 @@ class OneSignHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -194,7 +195,7 @@ class WeeklySignHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -238,7 +239,7 @@ class CumulativeSignHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -341,9 +342,10 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
-        module_id = int(self.get_param("module_id", 0))
+        mix_nick = self.get_param("mix_nick")
+        module_id = self.get_param_int("module_id", 0)
         login_token = self.get_param("login_token")
-        from_user_id = int(self.get_param("invite_user_id", 0))
+        from_user_id = self.get_param_int("invite_user_id", 0)
         task_base_model = TaskBaseModel(context=self)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -357,7 +359,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         access_token = app_info_dict["access_token"] if app_info_dict else ""
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire, close_invite_limit)
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, mix_nick, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -463,7 +465,7 @@ class FavorStoreHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -504,7 +506,7 @@ class JoinMemberHandler(ClientBaseHandler):
         :param module_id:活动模块标识
         :param user_code:用户标识
         :param login_token:访问令牌
-        :return: 
+        :return: 直接发放奖励，返回奖励值
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -587,12 +589,12 @@ class BrowseSiteHandler(ClientBaseHandler):
 
 class ShareHandler(ClientBaseHandler):
     """
-    :description: 分享奖励任务
+    :description: 分享任务
     """
     @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
-        :description: 分享奖励任务
+        :description: 分享任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
