@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-11-29 10:48:40
+@LastEditTime: 2023-01-04 16:24:28
 @LastEditors: HuangJianYi
 @Description: 
 """
+from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.order_base_model import *
@@ -33,7 +34,7 @@ class LoginHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         open_id = self.get_param("open_id")
-        user_nick = self.get_param("user_nick")
+        user_nick = self.get_user_nick()
         act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         avatar = self.get_param("avatar")
@@ -115,7 +116,7 @@ class UpdateUserInfoHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         open_id = self.get_param("open_id")
-        user_nick = self.get_param("user_nick")
+        user_nick = self.get_user_nick()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         avatar = self.get_param("avatar")
@@ -330,17 +331,19 @@ class AssetLogListHandler(ClientBaseHandler):
         :param operate_type：操作类型(0累计 1消耗
         :param page_size：条数
         :param page_index：页数
+        :param page_count_mode：分页模式(0-none 1-total 2-next)
         :return list
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
-        asset_type = int(self.get_param("asset_type", 0))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
+        asset_type = self.get_param_int("asset_type", 0)
         asset_object_id = self.get_param("asset_object_id")
-        operate_type = int(self.get_param("operate_type", -1))
+        operate_type = self.get_param_int("operate_type", -1)
+        page_count_mode = self.get_param_int("page_count_mode", 1)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -349,10 +352,19 @@ class AssetLogListHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        page_list, total = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type)
-        ref_params = {}
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
-        return self.response_json_success(page_info)
+        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
+        page_list = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type, page_count_mode=page_count_mode)
+        if page_count_mode == "total":
+            total = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = PageInfo(page_index, page_size, total, page_list)
+        elif page_count_mode == "next":
+            is_next = page_list[1]
+            page_list = self.business_process_executed(page_list[0], ref_params={})
+            return_info = WaterPageInfo(page_list, is_next)
+        else:
+            return_info = self.business_process_executed(page_list, ref_params={})
+        return self.response_json_success(return_info)
 
 
 class GetJoinMemberUrlHandler(ClientBaseHandler):
