@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-11-25 09:19:23
+@LastEditTime: 2022-12-13 15:46:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -409,7 +409,9 @@ class FrameBaseHandler(BaseApiHandler):
         :return str
         :last_editors: HuangJianYi
         """
-        user_nick = self.get_param("user_nick")
+        user_nick = self.get_param("nick_name")
+        if not user_nick:
+            user_nick = self.get_param("user_nick")
         plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
         if plat_type == 1:
             #淘宝小程序 source_app_id在本地环境返回空；在test和online环境返回后端模板id，无论在IDE还是千牛端
