@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-10-21 11:17:40
+@LastEditTime: 2023-01-17 19:00:32
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -55,12 +55,35 @@ class AddActInfoHandler(ClientBaseHandler):
         """
         :description: 添加活动信息
         :param app_id：应用标识
-        :param act_name: 活动名称
-        :param act_type: 活动类型
+        :param act_id：活动标识
+        :param act_name：活动名称
+        :param is_release：是否发布
         :param theme_id: 主题标识
+        :param is_share: 是否开启分享
         :param share_desc_json: 分享配置
+        :param is_rule: 是否开启规则
         :param rule_desc_json: 规则配置
+        :param start_date: 开始时间
+        :param end_date: 结束时间
         :param close_word: 关闭文案
+        :param is_black：是否开启退款惩罚
+        :param refund_count：退款成功次数
+        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
+        :param is_fictitious: 是否开启虚拟中奖（1是0否）
+        :param i1: i1
+        :param i2: i2
+        :param i3: i3
+        :param i4: i4
+        :param i5: i5
+        :param s1: s1
+        :param s2: s2
+        :param s3: s3
+        :param s4: s4
+        :param s5: s5
+        :param d1: d1
+        :param d2: d2
+        :param agreement_json: 协议配置（用户协议或隐私条款）
+        :param brand_json: 品牌配置
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -68,18 +91,46 @@ class AddActInfoHandler(ClientBaseHandler):
         act_type = int(self.get_param("act_type", 0))
         theme_id = int(self.get_param("theme_id", 0))
         close_word = self.get_param("close_word","抱歉，程序维护中")
-        share_desc_json = self.get_param("share_desc_json", "")
-        rule_desc_json = self.get_param("rule_desc_json", "")
+        share_desc_json = self.get_param("share_desc_json", None)
+        rule_desc_json = self.get_param("rule_desc_json", None)
+        is_share = self.get_param_int("is_share", 0)
+        is_rule = self.get_param_int("is_rule", 0)
+        is_release = self.get_param_int("is_release", 0)
+        start_date = self.get_param("start_date", None)
+        end_date = self.get_param("end_date", None)
+        is_black = int(self.get_param("is_black", -1))
+        refund_count = int(self.get_param("refund_count", -1))
+        join_ways = int(self.get_param("join_ways", -1))
+        is_fictitious = int(self.get_param("is_fictitious", -1))
+        store_url = self.get_param("store_url", None)
+        i1 = int(self.get_param("i1", -1))
+        i2 = int(self.get_param("i2", -1))
+        i3 = int(self.get_param("i3", -1))
+        i4 = int(self.get_param("i4", -1))
+        i5 = int(self.get_param("i5", -1))
+        s1 = self.get_param("s1", None)
+        s2 = self.get_param("s2", None)
+        s3 = self.get_param("s3", None)
+        s4 = self.get_param("s4", None)
+        s5 = self.get_param("s5", None)
+        d1 = self.get_param("d1", None)
+        d2 = self.get_param("d2", None)
+        is_visit_store = int(self.get_param("is_visit_store", -1))
+        agreement_json = self.get_param("agreement_json", None)
+        brand_json = self.get_param("brand_json", None)
+
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word)
+        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word, is_share, is_rule, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title= title_prefix + act_name)
+        self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title= title_prefix + ";" + act_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -122,6 +173,8 @@ class UpdateActInfoHandler(ClientBaseHandler):
         :param s5: s5
         :param d1: d1
         :param d2: d2
+        :param agreement_json: 协议配置（用户协议或隐私条款）
+        :param brand_json: 品牌配置
         :return: 
         :last_editors: HuangJianYi
         """
@@ -155,16 +208,20 @@ class UpdateActInfoHandler(ClientBaseHandler):
         s5 = self.get_param("s5", None)
         d1 = self.get_param("d1", None)
         d2 = self.get_param("d2", None)
+        agreement_json = self.get_param("agreement_json", None)
+        brand_json = self.get_param("brand_json", None)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store)
+        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.update.value, model_name="act_info_tb", old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=title_prefix + act_name)
+        self.create_operation_log(operation_type=OperationType.update.value, model_name="act_info_tb", old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=title_prefix + ";" + act_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -182,6 +239,7 @@ class ActInfoListHandler(ClientBaseHandler):
         :param app_id：应用标识
         :param act_name: 活动名称
         :param is_del: 是否回收站1是0否
+        :param is_release: 是否发布1是0否
         :param page_size: 条数
         :param page_index: 页数
         :return: PageInfo
@@ -191,6 +249,8 @@ class ActInfoListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         is_del = int(self.get_param("is_del", -1))
+        is_release = int(self.get_param("is_release", -1))
+        act_type = int(self.get_param("act_type", -1))
         act_name = self.get_param("act_name")
 
         invoke_result_data = self.business_process_executing()
@@ -200,7 +260,7 @@ class ActInfoListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
-        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index,False)
+        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release)
         for page in page_list:
             page["online_url"] = app_base_model.get_online_url(page['id'], app_id)
             page["live_url"] = app_base_model.get_live_url(app_id)
@@ -233,9 +293,11 @@ class ActInfoHandler(ClientBaseHandler):
             if act_info_dict["app_id"] != app_id:
                 act_info_dict = {}
                 return self.response_json_success(act_info_dict)
+            act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
             act_info_dict["share_desc_json"] = self.json_loads(act_info_dict["share_desc_json"]) if act_info_dict["share_desc_json"] else {}
             act_info_dict["rule_desc_json"] = self.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
-            act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
+            act_info_dict["agreement_json"] = self.json_loads(act_info_dict["agreement_json"]) if act_info_dict["agreement_json"] else []
+            act_info_dict["brand_json"] = self.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}
             act_info_dict['online_url'] = app_base_model.get_online_url(act_info_dict['id'], act_info_dict['app_id'])
             act_info_dict['live_url'] = app_base_model.get_live_url(act_info_dict['app_id'])
         ref_params = {}
@@ -259,12 +321,14 @@ class DeleteActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -289,12 +353,14 @@ class ReviewActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 0)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -321,13 +387,15 @@ class ReleaseActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.release_act_info(app_id, act_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=operation_type, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
