@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2022-07-20 18:10:31
+@LastEditTime: 2022-10-17 17:33:38
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
+from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.app_base_model import *
@@ -31,6 +32,7 @@ class InstantiateAppHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         user_nick = self.get_user_nick()
         access_token = self.get_access_token()
+        main_user_open_id = self.get_param("main_user_open_id")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
 
@@ -42,7 +44,7 @@ class InstantiateAppHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
         app_key, app_secret = self.get_app_key_secret()
         top_base_model = TopBaseModel(context=self)
-        invoke_result_data = top_base_model.instantiate(app_id, user_nick, access_token, app_key, app_secret, is_log)
+        invoke_result_data = top_base_model.instantiate(app_id, user_nick, access_token, app_key, app_secret, is_log, main_user_open_id)
         if invoke_result_data.success == False:
             SevenHelper.redis_init().delete(cache_key)
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
@@ -143,9 +145,10 @@ class AppInfoHandler(ClientBaseHandler):
         :return app_info
         :last_editors: HuangJianYi
         """
+        main_user_open_id = self.get_param("main_user_open_id")
         app_base_model = AppBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_access_token(), app_key, app_secret)
+        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_access_token(), app_key, app_secret, main_user_open_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -315,6 +318,15 @@ class UpdateStoreAssetHandler(ClientBaseHandler):
         invoke_result_data = asset_base_model.update_store_asset(app_id, store_id, store_name, asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        title = "资产配置；"
+        if asset_type == 1:
+            title = "次数配置；"
+        elif asset_type == 2:
+            title = "积分配置；"
+        elif asset_type == 3:
+            title = "档位配置；"
+        title = title + "店铺名称：" + store_name + "，store_id：" + store_id
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="store_asset_tb", title=title)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
