@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2022-10-28 11:47:23
+@LastEditTime: 2023-01-12 09:52:44
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -279,14 +279,14 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        default_prefix = "资产配置；"
+        default_prefix = "资产配置"
         operation_desc = ""
         if asset_type == 1:
-            default_prefix = "次数配置；"
+            default_prefix = "次数配置"
         elif asset_type == 2:
-            default_prefix = "积分配置；"
+            default_prefix = "积分配置"
         elif asset_type == 3:
-            default_prefix = "价格档位配置；"
+            default_prefix = "价格档位配置"
             price_gear_model = PriceGearModel(context=self)
             asset_object_id = int(asset_object_id)
             if asset_object_id > 0:
@@ -294,7 +294,7 @@ class UpdateUserAssetHandler(ClientBaseHandler):
                 if price_gear:
                     operation_desc = "价格档位:" + price_gear.price_gear_name + "，次数：" + str(asset_value)
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
-        title = title_prefix + "用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
+        title = title_prefix + ";" + "用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
         self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_asset_tb", title=title, operation_desc=operation_desc)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
