@@ -8,9 +8,7 @@
 """
 import oss2
 import os
-
-from seven_framework.uuid import *
-from seven_framework import ExcelHelper, config
+from seven_framework import *
 
 
 class OSS2Helper:
@@ -20,6 +18,8 @@ class OSS2Helper:
     :return: 
     :last_editors: HuangJianYi
     """
+    logger_error = Logger.get_logger_by_name("log_error")
+
     @classmethod
     def get_oss_config(self):
         oss_config = config.get_value("oss_config")
@@ -35,6 +35,7 @@ class OSS2Helper:
         self.bucket_name = oss_config.get("bucket_name","")
         self.end_point = oss_config.get("end_point","")
         self.demain = oss_config.get("demain","")
+    
     @classmethod
     def upload(self, file_name, local_file='', folder='', is_auto_name=True, data=None):
         """
@@ -105,5 +106,5 @@ class OSS2Helper:
                 resource_path = self.upload("", path, config.get_value("oss_folder"), False)
                 os.remove(path)
             except Exception as ex:
-                pass
+                self.logger_error("【数据导入excel】" + traceback.format_exc())
         return resource_path
\ No newline at end of file
