@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-07-20 17:06:10
+@LastEditTime: 2022-07-27 15:52:08
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -158,40 +158,49 @@ class SevenHelper:
         return s_model
 
     @classmethod
-    def get_condition_by_str_list(self, field_name, str_list):
+    def get_condition_by_str_list(self, field_name, str_list, is_in=True):
         """
         :description: 根据str_list返回查询条件 in查询参数化，如：act_info_model.get_list("FIND_IN_SET(act_name,%s)", params=['活动1,活动2'])
         :param field_name: 字段名
         :param str_list: 字符串数组
+        :param is_in: 是否in查询，是in查询 否not in 查询
         :return: 
         :last_editors: HuangJianYi
         """
         if not str_list:
             return ""
         list_str = ','.join(["'%s'" % str(item) for item in str_list])
-        return f"{field_name} IN({list_str})"
+        if is_in:
+            return f"{field_name} IN({list_str})"
+        else:
+            return f"{field_name} NOT IN({list_str})"
 
     @classmethod
-    def get_condition_by_int_list(self, field_name, int_list=None):
+    def get_condition_by_int_list(self, field_name, int_list, is_in=True):
         '''
         :description: 根据int_list返回查询条件 in查询参数化，如：act_info_model.get_list("FIND_IN_SET(act_name,%s)", params=['活动1,活动2'])
         :param field_name:字段名
         :param int_list:整形数组
+        :param is_in: 是否in查询，是in查询 否not in 查询
         :return: str
         :last_editors: HuangJianYi
         '''
         if not int_list:
             return ""
         list_str = str(int_list).strip('[').strip(']')
-        return f"{field_name} IN({list_str})"
+        if is_in:
+            return f"{field_name} IN({list_str})"
+        else:
+            return f"{field_name} NOT IN({list_str})"
 
     @classmethod
-    def get_condition_in(self, field_name, field_str, field_type=1):
+    def get_condition_in(self, field_name, field_str, field_type=1, is_in=True):
         '''
         :description: 根据逗号分隔字符串合成条件
         :param field_name:字段名
         :param field_str:逗号分隔字符串
         :param field_type:字段类型（1整形2字符串）
+        :param is_in: 是否in查询，是in查询 否not in 查询
         :return: 查询字符串
         :last_editors: HuangJianYi
         '''
@@ -209,7 +218,10 @@ class SevenHelper:
         else:
             str_list = field_str.split(",")
             list_str = ','.join(["'%s'" % str(item) for item in str_list])
-        return f"{field_name} IN({list_str})"
+        if is_in:
+            return f"{field_name} IN({list_str})"
+        else:
+            return f"{field_name} NOT IN({list_str})"
 
     @classmethod
     def is_ip(self, ip_str):
