@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-09-28 11:55:20
+@LastEditTime: 2022-11-23 19:00:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -176,7 +176,7 @@ class AppBaseModel():
         invoke_result_data.data =data
         return invoke_result_data
 
-    def get_app_info_result(self, user_nick, open_id, access_token, app_key, app_secret):
+    def get_app_info_result(self, user_nick, open_id, access_token, app_key, app_secret, main_user_open_id=""):
         """
         :description: 获取小程序信息
         :param user_nick:用户昵称
@@ -184,6 +184,7 @@ class AppBaseModel():
         :param access_token: access_token
         :param app_key:app_key
         :param app_secret: app_secret
+        :param main_user_open_id: main_user_open_id
         :return app_info
         :last_editors: HuangJianYi
         """
@@ -218,7 +219,9 @@ class AppBaseModel():
             invoke_result_data = top_base_model.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
-            app_info_model.update_entity(app_info,"expiration_date,project_code,access_token")
+            if app_info.main_user_open_id != main_user_open_id:
+                app_info.main_user_open_id = main_user_open_id
+            app_info_model.update_entity(app_info,"expiration_date,project_code,access_token,main_user_open_id")
             app_info_model.delete_dependency_key(f"app_info:appid_{app_info.app_id}")
 
             app_info.user_nick = user_nick
