@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-11-22 14:32:04
+@LastEditTime: 2023-01-04 16:20:23
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -19,7 +19,7 @@ from seven_cloudapp_frame.models.frame_base_model import *
 
 class AssetBaseModel():
     """
-    :description: 资产管理业务模型
+    :description: 资产管理业务模型,主要管理用户资产和商家资产
     """
     def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
@@ -337,8 +337,6 @@ class AssetBaseModel():
                 self.context.logging_link_error("【变更资产】" + traceback.format_exc())
             elif self.logging_link_error:
                 self.logging_link_error("【变更资产】" + traceback.format_exc())
-            if db_transaction.is_transaction == True:
-                db_transaction.rollback_transaction()
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -407,7 +405,7 @@ class AssetBaseModel():
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type=0, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1):
+    def get_asset_log_list(self, app_id, act_id, asset_type=0, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1, page_count_mode="total"):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -426,11 +424,11 @@ class AssetBaseModel():
         :param field：查询字段
         :param is_cache：是否缓存
         :param operate_type：操作类型 （0累计 1消耗）
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算       
         :return: 
         :last_editors: HuangJianYi
         """
         page_list = []
-        total = 0
 
         condition = "act_id=%s"
         params = [act_id]
@@ -476,15 +474,26 @@ class AssetBaseModel():
                 params.append(source_object_id)
         asset_log_model = AssetLogModel(context=self.context)
         if is_cache:
-            page_list, total = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=DependencyKey.asset_log_list(act_id,user_id))
+            page_list = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params, dependency_key=DependencyKey.asset_log_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
-            page_list, total = asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
+            page_list = asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params, page_count_mode=page_count_mode)
+        result = None
+        if page_count_mode in ['total','next']:
+            result = page_list[1]
+            page_list = page_list[0]
         if len(page_list) > 0:
             for item in page_list:
                 if item["app_id"] != app_id:
-                    return [],0
+                    if page_count_mode == 'total':
+                        return [], 0
+                    elif page_count_mode == 'next':
+                        return [], False
+                    else:
+                        return []
                 item["create_day"] = TimeHelper.format_time_to_datetime(str(item["create_date"])).strftime('%Y-%m-%d')
-        return page_list,total
+        if page_count_mode in ['total','next']:
+            return page_list, result
+        return page_list
 
     def add_asset_log(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, history_asset_value=0, handler_name="", request_code="", info_json={}):
         """
@@ -554,9 +563,8 @@ class AssetBaseModel():
         :return: 返回PageInfo
         :last_editors: HuangJianYi
         """
-        page_info = PageInfo(page_index, page_size, 0, [])
-        if not act_id:
-            return page_info
+        page_list = []
+        total = 0
 
         condition = "act_id=%s and asset_type=%s"
         params = [act_id, asset_type]
@@ -589,10 +597,8 @@ class AssetBaseModel():
         if len(page_list) > 0:
             for item in page_list:
                 if item["app_id"] != app_id:
-                    return page_info
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
-
+                    return [],0
+        return page_list, total
 
     def update_store_asset(self, app_id,store_id, store_name, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, db_connect_key='db_cloudapp', handler_name="",request_code="", info_json={}):
         """
@@ -737,8 +743,6 @@ class AssetBaseModel():
                 self.context.logging_link_error("【变更商家资产】" + traceback.format_exc())
             elif self.logging_link_error:
                 self.logging_link_error("【变更商家资产】" + traceback.format_exc())
-            if db_transaction.is_transaction == True:
-                db_transaction.rollback_transaction()
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -863,9 +867,9 @@ class AssetBaseModel():
                 params.append(source_object_id)
         store_asset_log_model = StoreAssetLogModel(db_connect_key=db_connect_key,context=self.context)
         if is_cache:
-            page_list, total = store_asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=DependencyKey.store_asset_log_list(app_id))
+            page_list, total = store_asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params,dependency_key=DependencyKey.store_asset_log_list(app_id))
         else:
-            page_list, total = store_asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
+            page_list, total = store_asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
         if len(page_list) > 0:
             for item in page_list:
                 if item["app_id"] != app_id:
