@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-08-12 18:25:35
+@LastEditTime: 2022-12-19 09:46:51
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -217,7 +217,7 @@ class CacheModel(BaseModel):
             self.set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
             return self._BaseModel__row_entity_list(list_row)
 
-    def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=1800):
+    def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=1800, page_count_mode='total'):
         """
         :Description: 分页获取数据
         :param field: 查询字段 
@@ -229,6 +229,7 @@ class CacheModel(BaseModel):
         :param params: 参数化查询参数
         :param dependencyKey: 依赖键
         :param cache_expire: 缓存时间（单位秒）
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
         :return: 模型实体列表
         :last_editors: HuangJianYi
         """
@@ -238,31 +239,53 @@ class CacheModel(BaseModel):
             group_by = " GROUP BY " + group_by
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
-        limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
 
+        if page_count_mode == "next":
+            page_size = page_size + 1
+
+        limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit};"
-        count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
 
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('entitypagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
-            return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
-        else:
-            list_row = self.db.fetch_all_rows(sql, params)
-            row = self.db.fetch_one_row(count_sql, params)
-            if row and 'count' in row and int(row['count']) > 0:
-                row_count = int(row["count"])
+            if page_count_mode == "total":
+                return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
+            elif page_count_mode == "next":
+                return self._BaseModel__row_entity_list(page_list["data"]),bool(page_list["is_next_page"])
             else:
-                row_count = 0
+                return self._BaseModel__row_entity_list(page_list["data"])
+        else:
             page_list = {}
-            page_list["data"] = list_row
-            page_list["row_count"] = row_count
-            config_cache_expire = config.get_value("cache_expire",0)
-            if config_cache_expire > 0:
-                cache_expire = config_cache_expire
-            self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
-            return self._BaseModel__row_entity_list(page_list["data"]), row_count
+            list_row = self.db.fetch_all_rows(sql, params)
+            if not list_row:
+                list_row = []
+            if page_count_mode == "total":
+                sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+                if group_by:
+                    sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
+                row = self.db.fetch_one_row(sql, params)
+                if row and 'count' in row and int(row['count']) > 0:
+                    row_count = int(row["count"])
+                else:
+                    row_count = 0
+                page_list["data"] = list_row
+                page_list["row_count"] = row_count
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return self._BaseModel__row_entity_list(page_list["data"]), row_count
+            elif page_count_mode == "next":
+                is_next_page = len(list_row) == page_size
+                if list_row and len(list_row)>0:
+                    list_row = list_row[:page_size-1]
+                page_list["data"] = list_row
+                page_list["is_next_page"] = is_next_page
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return self._BaseModel__row_entity_list(page_list["data"]), is_next_page
+            else:
+                page_list["data"] = list_row
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return self._BaseModel__row_entity_list(page_list["data"])
 
     def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=1800):
         """
@@ -485,7 +508,7 @@ class CacheModel(BaseModel):
                         one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return list_row
 
-    def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=1800):
+    def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' , params=None, dependency_key='', cache_expire=1800, page_count_mode='total'):
         """
         :Description: 获取分页字典数据
         :param field: 查询字段 
@@ -497,6 +520,7 @@ class CacheModel(BaseModel):
         :param params: 参数化查询参数
         :param dependencyKey: 依赖键
         :param cache_expire: 缓存时间（单位秒）
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
         :return: 数据字典数组
         :last_editors: HuangJianYi
         """
@@ -506,34 +530,60 @@ class CacheModel(BaseModel):
             group_by = " GROUP BY " + group_by
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
+
+        if page_count_mode == "next":
+            page_size = page_size + 1
+
         limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit}"
-        count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
-
+        
         dependency_key = self.get_dependency_key(str(dependency_key))
         cache_key = self.get_cache_key('dictpagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
-            return page_list["data"],page_list["row_count"]
-        else:
-            list_row = self.db.fetch_all_rows(sql, params)
-            row = self.db.fetch_one_row(count_sql, params)
-            if not list_row:
-                list_row = []
-            if row and 'count' in row and int(row['count']) > 0:
-                row_count = int(row["count"])
+            if page_count_mode == "total":
+                return page_list["data"],page_list["row_count"]
+            elif page_count_mode == "next":
+                return page_list["data"],bool(page_list["is_next_page"])
             else:
-                row_count = 0
-            page_list = {}
-            page_list["data"] = list_row
-            page_list["row_count"] = row_count
+                return page_list["data"]
+        else:
             config_cache_expire = config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
-            self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            page_list = {}
+            list_row = self.db.fetch_all_rows(sql, params)
+            if not list_row:
+                list_row = []
             if list_row and len(list_row) > 0:
-                for one_row in list_row:
-                    for field in one_row:
-                        one_row[field] = self._BaseModel__convert_field_type(one_row[field])
-            return list_row, row_count
+                    for one_row in list_row:
+                        for field in one_row:
+                            one_row[field] = self._BaseModel__convert_field_type(one_row[field])
+            if page_count_mode == "total":
+                sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+                if group_by:
+                    sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
+                row = self.db.fetch_one_row(sql, params)
+                if row and 'count' in row and int(row['count']) > 0:
+                    row_count = int(row["count"])
+                else:
+                    row_count = 0
+                page_list["data"] = list_row
+                page_list["row_count"] = row_count
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return list_row, row_count
+            elif page_count_mode == "next":
+                is_next_page = len(list_row) == page_size
+                if list_row and len(list_row)>0:
+                    list_row = list_row[:page_size-1]
+                page_list["data"] = list_row
+                page_list["is_next_page"] = is_next_page
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return list_row, is_next_page
+            else:
+                page_list["data"] = list_row
+                self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+                return list_row
+
+            
     
\ No newline at end of file
