@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-11-25 14:24:43
+@LastEditTime: 2022-12-13 10:38:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -143,8 +143,6 @@ class StatConsoleModel():
                             if result == False:
                                 raise Exception("执行事务失败", message)
                         except Exception as ex:
-                            if db_transaction.is_transaction == True:
-                                db_transaction.rollback_transaction()
                             stat_queue.process_count += 1
                             if stat_queue.process_count <= 10:
                                 stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}"
@@ -243,8 +241,6 @@ class StatConsoleModel():
                     redis_init.lpop(redis_stat_key)
 
                 except Exception as ex:
-                    if db_transaction.is_transaction == True:
-                        db_transaction.rollback_transaction()
                     logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
 
@@ -323,8 +319,6 @@ class StatConsoleModel():
                     redis_init.lpop(redis_stat_key)
 
                 except Exception as ex:
-                    if db_transaction.is_transaction == True:
-                        db_transaction.rollback_transaction()
                     logger_error.error(f"统计用户队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
 
