@@ -1,3 +1,11 @@
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2021-08-19 22:41:48
+@LastEditTime: 2021-09-02 18:30:45
+@LastEditors: HuangJianYi
+@Description: 
+"""
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -18,7 +26,8 @@ class AssetInventory:
 
     def __init__(self):
         super(AssetInventory, self).__init__()
-        self.id = 0  # id(act_id+user_id+asset_type+asset_object_id+create_day)md5int生成
+        self.id = 0  # id
+        self.id_md5 = 0  # id_md5(act_id+user_id+asset_type+asset_object_id+create_day)md5int生成
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.user_id = 0  # 用户标识
@@ -37,7 +46,7 @@ class AssetInventory:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'asset_type', 'asset_object_id', 'inc_value', 'dec_value', 'history_value', 'now_value', 'create_date', 'create_day', 'process_count', 'process_date']
+        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'asset_type', 'asset_object_id', 'inc_value', 'dec_value', 'history_value', 'now_value', 'create_date', 'create_day', 'process_count', 'process_date']
 
     @classmethod
     def get_primary_key(self):
