@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 17:17:08
-@LastEditTime: 2021-09-02 18:30:53
+@LastEditTime: 2021-09-02 20:41:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -27,7 +27,7 @@ class AssetOnly:
     def __init__(self):
         super(AssetOnly, self).__init__()
         self.id = 0  # id
-        self.id = 0  # id(act_id+user_id+only_id)md5int生成
+        self.id_md5 = 0  # id_md5(act_id+user_id+only_id)md5int生成
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动ID
         self.user_id = 0  # 用户标识
@@ -37,7 +37,7 @@ class AssetOnly:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'only_id', 'create_date']
+        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'open_id', 'only_id', 'create_date']
 
     @classmethod
     def get_primary_key(self):
