@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-09-26 15:19:56
-@LastEditTime: 2022-09-27 09:19:43
+@LastEditTime: 2022-09-28 11:13:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -27,6 +27,7 @@ class DictInfo:
     def __init__(self):
         super(DictInfo, self).__init__()
         self.id = 0  # id
+        self.dict_type = 0  # 字典类型
         self.dict_name = ""  # 字典名称
         self.dict_value = ""  # 字典值
         self.dict_pic = ""  # 字典图片
@@ -42,7 +43,7 @@ class DictInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'dict_name', 'dict_value', 'dict_pic', 'sort_index', 'is_release', 'create_date', 'modify_date', 'parent_id', 'i1', 'i2', 's1', 's2']
+        return ['id', 'dict_type', 'dict_name', 'dict_value', 'dict_pic', 'sort_index', 'is_release', 'create_date', 'modify_date', 'parent_id', 'i1', 'i2', 's1', 's2']
 
     @classmethod
     def get_primary_key(self):
