@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2022-06-10 13:32:59
+@LastEditTime: 2022-09-28 17:52:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,6 +30,7 @@ class IpInfo:
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.ip_name = ""  # ip名称
+        self.mode_type = 0  # 模式类型
         self.ip_type = 0  # ip类型
         self.ip_pic = ""  # ip图片
         self.show_pic = ""  # 展示图片
@@ -40,11 +41,12 @@ class IpInfo:
         self.del_date = "1900-01-01 00:00:00"  # 删除时间
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.modify_date = "1900-01-01 00:00:00"  # 修改时间
+        self.ip_config_json = ""  # 配置信息json
 
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'ip_name', 'ip_type', 'ip_pic', 'show_pic', 'ip_summary', 'sort_index', 'is_release', 'is_del', 'del_date', 'create_date', 'modify_date']
+        return ['id', 'app_id', 'act_id', 'ip_name', 'mode_type', 'ip_type', 'ip_pic', 'show_pic', 'ip_summary', 'sort_index', 'is_release', 'is_del', 'del_date', 'create_date', 'modify_date', 'ip_config_json']
 
     @classmethod
     def get_primary_key(self):
