@@ -33,7 +33,7 @@ class UserAsset:
         self.user_id = 0  # 用户标识
         self.open_id = ""  # open_id
         self.user_nick = ""  # 用户昵称
-        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位，业务自定义类型从101起，避免跟公共冲突)
+        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位4-运费券，业务自定义类型从101起，避免跟公共冲突)
         self.asset_object_id = ""  # 资产对象标识
         self.asset_value = 0  # 资产值
         self.asset_check_code = ""  # 资产检验码(id+asset_value+加密签名)md5生成
