@@ -357,7 +357,7 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "no_authorize"
                 invoke_result_data.error_message = "对不起,请先授权"
                 return invoke_result_data
-        if user_info_dict["login_token"] != login_token:
+        if login_token and user_info_dict["login_token"] != login_token:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "已在另一台设备登录,无法操作"
@@ -411,7 +411,7 @@ class FrameBaseModel():
         """
         invoke_result_data = InvokeResultData()
 
-        if not act_id or not user_id or not login_token or not handler_name:
+        if not act_id or not user_id or not handler_name:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
