@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2022-09-27 18:24:55
+@LastEditTime: 2022-10-17 14:17:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,7 +100,7 @@ class ModuleBaseModel():
             page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
-    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2,business_type):
+    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2,business_type=0):
         """
         :description: 添加活动模块信息
         :param app_id: 应用标识
@@ -224,6 +224,7 @@ class ModuleBaseModel():
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_module_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, module_id])
         self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
+        invoke_result_data.data = act_module_dict
         return invoke_result_data
 
     def release_act_module(self,app_id,module_id,is_release):
@@ -245,6 +246,7 @@ class ModuleBaseModel():
             return invoke_result_data
         invoke_result_data.success = act_module_model.update_table("release_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, module_id])
         self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
+        invoke_result_data.data = act_module_dict
         return invoke_result_data
 
     def update_act_module_price(self,app_id,act_id,prize_gear_id):
