@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-10-17 15:37:37
+@LastEditTime: 2023-01-30 17:29:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -56,7 +56,7 @@ class OrderBaseModel(FrameBaseModel):
         """
         PrizeRosterModel().delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id), delay_delete_time)
 
-    def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
+    def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None, page_count_mode="total"):
         """
         :description: 用户奖品订单列表
         :param app_id：应用标识
@@ -79,20 +79,18 @@ class OrderBaseModel(FrameBaseModel):
         :param is_cache：是否缓存
         :param condition：条件
         :param params：参数化数组
-        :param prize_roster_sub_table：奖品记录分表名称       
-        :return: PageInfo
+        :param prize_roster_sub_table：奖品记录分表名称
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算       
+        :return:
         :last_editors: HuangJianYi
         """
+        page_list = []
+
         where = "app_id=%s and act_id=%s"
         params_list = [app_id,act_id]
         if condition:
             where += " AND " + condition
             params_list.extend(params)
-        page_list = []
-        total = 0
-
-        if not app_id or not act_id:
-            return page_list, total
         if user_id:
             where += " AND user_id=%s"
             params_list.append(user_id)
@@ -126,9 +124,13 @@ class OrderBaseModel(FrameBaseModel):
             params_list.append(create_date_end)
         prize_order_model = PrizeOrderModel(context=self.context)
         if is_cache:
-            page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, DependencyKey.prize_order_list(act_id,user_id))
+            page_list = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key=DependencyKey.prize_order_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
-            page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
+            page_list = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, page_count_mode)
+        result = None
+        if page_count_mode in ['total','next']:
+            result = page_list[1]
+            page_list = page_list[0]
         if is_search_roster == True:
             prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
             if page_list and len(page_list)>0:
@@ -137,7 +139,9 @@ class OrderBaseModel(FrameBaseModel):
                 for i in range(len(page_list)):
                     roster_list = [prize_roster for prize_roster in prize_roster_list_dict if page_list[i]["order_no"] == prize_roster["order_no"]]
                     page_list[i]["roster_list"] = roster_list
-        return page_list, total
+        if page_count_mode in ['total','next']:
+            return page_list, result
+        return page_list
 
     def update_prize_order_status(self,app_id,act_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
         """
@@ -202,8 +206,6 @@ class OrderBaseModel(FrameBaseModel):
                 self.context.logging_link_error(traceback.format_exc())
             elif self.logging_link_error:
                 self.logging_link_error(traceback.format_exc())
-            if db_transaction.is_transaction == True:
-                db_transaction.rollback_transaction()
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="操作失败"
@@ -464,7 +466,7 @@ class OrderBaseModel(FrameBaseModel):
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 return invoke_result_data
         else:
-            prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0")
+            prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0",params=[act_id])
 
         prize_order_model = PrizeOrderModel(context=self.context)
         now_date = SevenHelper.get_now_datetime()
@@ -497,8 +499,6 @@ class OrderBaseModel(FrameBaseModel):
             if result == False:
                 raise Exception("执行事务失败",message)
         except Exception as ex:
-            if db_transaction.is_transaction == True:
-                db_transaction.rollback_transaction()
             if self.context:
                 self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
             elif self.logging_link_error:
@@ -643,7 +643,7 @@ class OrderBaseModel(FrameBaseModel):
                     all_order_list = []
                     if asset_type == 3:
                         price_base_model = PriceBaseModel(context=self.context)
-                        price_gear_dict_list,total = price_base_model.get_price_gear_list(app_id,act_id,100,0)
+                        price_gear_dict_list = price_base_model.get_price_gear_list(app_id,act_id,100,0,page_count_mode='none')
                         for price_gear_dict in price_gear_dict_list:
                             goods_ids_list.append(price_gear_dict["goods_id"])
                     else:
@@ -780,7 +780,7 @@ class OrderBaseModel(FrameBaseModel):
 
         return invoke_result_data
 
-    def get_prize_roster_list(self,app_id,act_id,module_id,user_id,open_id="",user_nick="",order_no="",goods_type=-1,prize_type=-1,logistics_status=-1,prize_status=-1,pay_status=-1,page_size=20,page_index=0,create_date_start="",create_date_end="",order_by="create_date desc",field="*",condition="",params=[],is_cache=True):
+    def get_prize_roster_list(self,app_id,act_id,module_id,user_id,open_id="",user_nick="",order_no="",goods_type=-1,prize_type=-1,logistics_status=-1,prize_status=-1,pay_status=-1,page_size=20,page_index=0,create_date_start="",create_date_end="",order_by="create_date desc",field="*",condition="",params=[],is_cache=True, page_count_mode="total"):
         """
         :description: 用户中奖记录列表
         :description: 如果有进行数据缓存，创建中奖记录时需清掉依赖建
@@ -805,18 +805,18 @@ class OrderBaseModel(FrameBaseModel):
         :param condition：条件
         :param params：参数化数组
         :param is_cache：是否缓存
-        :return: PageInfo
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :return:
         :last_editors: HuangJianYi
         """
+        return_info = []
         where = "app_id=%s AND act_id=%s"
         params_list = [app_id,act_id]
         if condition:
             where += " AND " + condition
             params_list.extend(params)
-        page_info = PageInfo(page_index, page_size, 0, [])
-
         if not app_id or not act_id:
-            return page_info
+            return return_info
         if module_id:
             where += " AND module_id=%s"
             params_list.append(module_id)
@@ -856,11 +856,10 @@ class OrderBaseModel(FrameBaseModel):
 
         prize_roster_model = PrizeRosterModel(context=self.context)
         if is_cache:
-            page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,DependencyKey.prize_roster_list(act_id,user_id))
+            page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
-            page_list, total = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+            page_list = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, page_count_mode)
+        return page_list
 
     def get_horseracelamp_list(self, act_id, module_id, is_search_module=False, condition="", params=[], page_size=30):
         """
@@ -883,12 +882,15 @@ class OrderBaseModel(FrameBaseModel):
         if condition:
             condition_where.add_condition(condition)
             params_list.extend(params)
-        act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_dict_list("act_id=%s and is_prize_notice=0 and is_del=0", params=[act_id],cache_expire=60)
+        act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_dict_list("act_id=%s and is_prize_notice=1 and is_del=0", params=[act_id],cache_expire=60)
         if act_prize_list_dict:
+            if len(act_prize_list_dict) > 100:
+                act_prize_list_dict = random.sample(act_prize_list_dict,50)
+
             prize_id_list = [str(i["id"]) for i in act_prize_list_dict]
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
-                condition_where.add_condition("prize_id not in (" + prize_ids + ")")
+                condition_where.add_condition("prize_id in (" + prize_ids + ")")
         prize_roster_model = PrizeRosterModel(context=self.context)
         prize_roster_list = prize_roster_model.get_cache_dict_list(condition_where.to_string(), "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params_list, cache_expire=60)
         total = int(len(prize_roster_list))
