@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2022-12-01 16:35:02
+@LastEditTime: 2022-12-15 10:43:25
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -55,11 +55,6 @@ class FileUploadInfo():
 class PageInfo():
     """
     :description: 分页列表实体
-    :param page_index：当前索引号
-    :param page_size：页大小
-    :param record_count：总记录数
-    :param data：数据
-    :return: PageInfo
     :last_editors: HuangJianYi
     """
     def __init__(self, page_index=0, page_size=10, record_count=0, data=None):
@@ -115,6 +110,25 @@ class PageInfo():
             self.is_previous = False
 
 
+class WaterPageInfo():
+    """
+    :description: 瀑布流分页列表实体
+    :last_editors: HuangJianYi
+    """
+    def __init__(self, data=None, is_next=False):
+        """
+        :description: 瀑布流分页列表实体
+        :param data：数据
+        :param is_next：是否有下一页（True是False否）
+        :return: WaterPageInfo
+        :last_editors: HuangJianYi
+        """
+        # 数据
+        self.data = data
+        # 是否下一页
+        self.is_next = is_next
+
+
 class ConditionWhere():
     """
     @description: 条件拼接实体
