@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-11-28 11:01:57
+@LastEditTime: 2022-12-13 10:38:16
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -262,12 +262,16 @@ class UserBaseModel(FrameBaseModel):
                 self.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
-         
+        if not user_info:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "fail"
+            invoke_result_data.error_message = "登录失败"
+            return invoke_result_data
+
         user_info_dict = user_info.__dict__
-        if user_info_dict:
-            user_info_dict["telephone"] = user_account.telephone if user_account else ""
-            user_info_dict["sex"] = user_account.sex if user_account else 0
-            user_info_dict["birthday"] = user_account.birthday if user_account and user_account.birthday != "1900-01-01" else ""
+        user_info_dict["telephone"] = user_account.telephone if user_account else ""
+        user_info_dict["sex"] = user_account.sex if user_account else 0
+        user_info_dict["birthday"] = user_account.birthday if user_account and user_account.birthday != "1900-01-01" else ""
         invoke_result_data.data = user_info_dict
         return invoke_result_data
 
@@ -454,8 +458,6 @@ class UserBaseModel(FrameBaseModel):
             self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
             self._delete_user_black_cache(act_id, user_id)
         except Exception as ex:
-            if db_transaction.is_transaction == True:
-                db_transaction.rollback_transaction()
             if self.context:
                 self.context.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
             elif self.logging_link_error:
